# eric7.MicroPython.BluetoothDialogs

Package implementing Bluetooth related dialogs.

### Modules

BluetoothAdvertisement | Module implementing a class to parse and store the Bluetooth device advertisement data.
BluetoothController | Module implementing the Bluetooth related functionality.
BluetoothScanWindow | Module implementing a dialog to scan for Bluetooth devices.
BluetoothStatusDialog | Module implementing a dialog to show Bluetooth related status information.